@@ -208,35 +208,9 @@ def editable_attrs(parser, token):
     return EditableAttrsNode(instance_var)
 
 
-def get_content_used_on_pages_json(instance):
-    page_content_items = instance.page_content_items.all()
-    json_pages = []
-    for page_content_item in page_content_items:
-        json_pages.append({
-            'title': page_content_item.page.title,
-            'url': page_content_item.page.get_absolute_url(),
-        })
-    return simplejson.dumps(json_pages)
-
-
-class ContentUsedOnPagesJSONNode(template.Node):
-
-    def __init__(self, instance_var):
-        self.instance_var = template.Variable(instance_var)
-
-    def render(self, context):
-        try:
-            instance = self.instance_var.resolve(context)
-            return get_content_used_on_pages_json(instance)
-        except template.VariableDoesNotExist:
-            return ''
-
-
-@register.tag(name='content_used_on_pages_json')
-def content_used_on_pages_json(parser, token):
-    try:
-        instance_var = token.split_contents()[1]
-    except ValueError:
-        raise template.TemplateSyntaxError, "%r tag requires one argument" % token.contents.split()[0]
-
-    return ContentUsedOnPagesJSONNode(instance_var)
+@register.filter(name='escape_json_for_html')
+def escape_json_for_html(value):
+    """
+    Escapes valid JSON for use in HTML, e.g. convert single quote to HTML character entity
+    """
+    return value.replace("'", "&#39;")
